======
SVVAMP
======


.. image:: https://img.shields.io/pypi/v/svvamp.svg
        :target: https://pypi.python.org/pypi/svvamp
        :alt: PyPI Status

.. image:: https://github.com/francois-durand/svvamp/workflows/build/badge.svg?branch=master
        :target: https://github.com/francois-durand/svvamp/actions?query=workflow%3Abuild
        :alt: Build Status

.. image:: https://github.com/francois-durand/svvamp/workflows/docs/badge.svg?branch=master
        :target: https://github.com/francois-durand/svvamp/actions?query=workflow%3Adocs
        :alt: Documentation Status


.. image:: https://codecov.io/gh/francois-durand/svvamp/branch/master/graphs/badge.svg
        :target: https://codecov.io/gh/francois-durand/svvamp/branch/master/graphs
        :alt: Code Coverage



Simulator of Various Voting Algorithms in Manipulating Populations


* Free software: GNU General Public License version 3.
* Code: https://github.com/francois-durand/svvamp.
* Documentation: https://francois-durand.github.io/svvamp/.


--------
Features
--------

*   Define profiles of voters with preferences over a set of candidates.
    Preferences can be generated by several probabilistic models,
    entered manually or imported from an external file.
*   Compute the result of several voting rules (ballots, winner, scores, etc).
*   Decide Condorcet notions.
*   Decide Independence of Irrelevant Alternatives.
*   Decide Individual Manipulation.
*   Decide Coalitional Manipulation and variants:
    Ignorant-Coalition Manipulation, Trivial Manipulation
    and Unison Manipulation.

-------
Credits
-------

This package was created with Cookiecutter_ and the `francois-durand/package_helper_2`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`francois-durand/package_helper_2`: https://github.com/francois-durand/package_helper_2
